Name:		blender
Version:	2.65a
%define subrel	1
Release:	%mkrel 5
Summary:	A fully functional 3D modeling/rendering/animation package
Group:		Graphics/3D
Source0:	http://download.blender.org/source/blender-%{version}.tar.gz
Patch0:		blender-2.65-localedir.patch
Patch1:		blender-2.60-error-when-missing-sse.patch
Patch2:		blender-2.58-static-lib.patch
Patch3:		blender-2.65-openjpeg_stdbool.patch
# Patch submitted upstream - Blender Patches item #19234,
Patch6:         blender-2.64-uninit-var.patch
Patch7:		blender-2.65-link.patch
Patch8:		blender-2.65-str-fmt.patch
Patch9:		blender-2.65a-minilzo.patch
URL:		http://www.blender.org/
License:	GPLv2+
BuildRequires:	cmake >= 2.8
BuildRequires:	ffmpeg-devel
BuildRequires:	glew-devel
BuildRequires:	OpenEXR-devel
BuildRequires:	SDL-devel
BuildRequires:	libx11-devel
BuildRequires:	libxi-devel
BuildRequires:	freetype2-devel
BuildRequires:	libgomp-devel
BuildRequires:	jpeg-devel
BuildRequires:	png-devel
BuildRequires:	openjpeg-devel
BuildRequires:	openal-devel
BuildRequires:	libsamplerate-devel
BuildRequires:	sndfile-devel
BuildRequires:	libjack-devel
BuildRequires:	tiff-devel
BuildRequires:	fftw3-devel
BuildRequires:	python3-devel >= 3.2
BuildRequires:	boost-devel
BuildRequires:	openimageio-devel
Buildrequires:	opencolorio-devel
Requires:	python(abi) >= 3.2
Requires(post,preun): GConf2

%description
Blender is the in-house software of a high quality animation studio.
It has proven to be an extremely fast and versatile design instrument.
The software has a personal touch, offering a unique approach to the
world of three dimensions. Blender can be used to create TV
commercials, to make technical visualizations or business graphics, to
do some morphing, or to design user interfaces. Developers can easily
build and manage complex environments. The renderer is versatile and
extremely fast. All basic animation principles (curves and keys) are
implemented.

%prep
%setup -qn %{name}-%{version}
%patch0 -p1 -b .localedir
%patch1 -p0 -b .sse
%patch2 -p0 -b .static
%patch3 -p1 -b .bool
%patch6 -p0
%patch7 -p0
%patch8 -p0
pushd extern/lzo
%patch9 -p0 -b .lzo
popd

%build
%ifarch %{ix86}
# build non-sse flavour
%cmake -DWITH_INSTALL_PORTABLE=OFF -DWITH_PLAYER=ON \
	-DWITH_PYTHON=ON -DWITH_PYTHON_INSTALL=OFF \
	-DPYTHON_VERSION=%{py3ver} -DWITH_BUILTIN_GLEW=OFF \
	-DWITH_CODEC_FFMPEG=ON -DWITH_CODEC_SNDFILE=ON \
	-DWITH_RAYOPTIMIZATION=OFF
%make
cd ..
mv build non-sse
%endif

#build sse flavour
%cmake -DWITH_INSTALL_PORTABLE=OFF -DWITH_PLAYER=ON \
	-DWITH_PYTHON=ON -DWITH_PYTHON_INSTALL=OFF \
	-DPYTHON_VERSION=%{py3ver} -DWITH_BUILTIN_GLEW=OFF \
	-DWITH_CODEC_FFMPEG=ON -DWITH_CODEC_SNDFILE=ON \
%ifarch %{ix86}
	-DSUPPORT_SSE2_BUILD=OFF \
%endif
	-DWITH_RAYOPTIMIZATION=ON
%make

%install
#install sse flavour
%makeinstall_std -C build

# Install hicolor icons.
for i in 16x16 22x22 32x32 48x48 256x256 ; do
  mkdir -p %{buildroot}%{_datadir}/icons/hicolor/${i}/apps
  install -pm 0644 release/freedesktop/icons/${i}/apps/%{name}.png \
    %{buildroot}%{_datadir}/icons/hicolor/${i}/apps/%{name}.png
done

mkdir -p %{buildroot}%{_datadir}/icons/hicolor/scalable/apps
install -pm 0644 release/freedesktop/icons/scalable/apps/%{name}.svg \
    %{buildroot}%{_datadir}/icons/hicolor/scalable/apps/%{name}.svg

%ifarch %{ix86}
mv %buildroot%_bindir/%name %buildroot%_bindir/%name.sse

#install non-sse flavour
rm -fr build
mv non-sse build
%makeinstall_std -C build
mv %buildroot%_bindir/%name %buildroot%_bindir/%name.nonsse

# install wrapper
cat >> %{buildroot}%{_bindir}/blender <<EOF 
if [ -e /proc/cpuinfo ]; then
	SSE="\`cat /proc/cpuinfo | grep flags | grep sse\`"
fi

if [ "x\$SSE" == x ]; then
	%{_bindir}/%{name}.nonsse "\$@"
else
	%{_bindir}/%{name}.sse "\$@"
fi
EOF
chmod 0755 %{buildroot}%{_bindir}/blender
%endif

sed -i -e 's,#!/usr/bin/python,#!/usr/bin/python3,' %{buildroot}%{_bindir}/blender-thumbnailer.py %{buildroot}%{_datadir}/%{name}/*/scripts/modules/blend_render_info.py

%find_lang %name

%clean
rm -rf %{buildroot}

%post
if [ -x %{_gconftool_bin} ]; then
   %{_gconftool_bin} --direct --config-source xml:readwrite:%{_sysconfdir}/gconf/gconf.xml.defaults --type boolean --set /desktop/gnome/thumbnailers/application@x-blender/enable true
   %{_gconftool_bin} --direct --config-source xml:readwrite:%{_sysconfdir}/gconf/gconf.xml.defaults --type string --set /desktop/gnome/thumbnailers/application@x-blender/command "blender-thumbnailer.py %u %o"
fi

%preun
if [ "$1" = "0" -a -x %{_gconftool_bin} ]; then
   %{_gconftool_bin} --direct --config-source xml:readwrite:%{_sysconfdir}/gconf/gconf.xml.defaults --unset /desktop/gnome/thumbnailers/application@x-blender/enable
   %{_gconftool_bin} --direct --config-source xml:readwrite:%{_sysconfdir}/gconf/gconf.xml.defaults --unset /desktop/gnome/thumbnailers/application@x-blender/command
fi

%files -f %name.lang
%doc release/text/*
%{_bindir}/*
%{_datadir}/applications/*.desktop
%{_datadir}/%{name}
%{_mandir}/man1/%{name}.1.*
%{_iconsdir}/hicolor/*/apps/%{name}.*


%changelog
* Wed Aug 20 2014 luigiwalser <luigiwalser> 2.65a-5.1.mga3
+ Revision: 666004
- rediff patch from harbour to fix CVE-2014-4607 in bundled minilzo

* Thu Apr 11 2013 barjac <barjac> 2.65a-5.mga3
+ Revision: 409767
- rebuild for boost-1.53

* Fri Jan 11 2013 umeabot <umeabot> 2.65a-4.mga3
+ Revision: 346914
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Tue Jan 08 2013 fwang <fwang> 2.65a-3.mga3
+ Revision: 341590
- rebuild for new ffmpeg

* Fri Dec 21 2012 cjw <cjw> 2.65a-2.mga3
+ Revision: 333650
- fix hardcoding of languages file location in patch0 that caused blender to crash at startup (mga #8394)

* Fri Dec 21 2012 fwang <fwang> 2.65a-1.mga3
+ Revision: 333544
- new version 2.65a

* Thu Dec 20 2012 fwang <fwang> 2.65-3.mga3
+ Revision: 332972
- rebuild for new boost

* Wed Dec 12 2012 fwang <fwang> 2.65-2.mga3
+ Revision: 329934
- br fftw3

* Wed Dec 12 2012 fwang <fwang> 2.65-1.mga3
+ Revision: 329929
- move languages file into datadir
- new version 2.65

* Sun Dec 02 2012 fwang <fwang> 2.64a-5.mga3
+ Revision: 325003
- rebuild for new openexr

* Sun Nov 11 2012 fwang <fwang> 2.64a-4.mga3
+ Revision: 316919
- br jack (bug#7952)

* Mon Oct 15 2012 fwang <fwang> 2.64a-3.mga3
+ Revision: 306643
- br opencolorio

* Wed Oct 10 2012 fwang <fwang> 2.64a-2.mga3
+ Revision: 304048
- drop support on sse2 in x86 build

* Wed Oct 10 2012 fwang <fwang> 2.64a-1.mga3
+ Revision: 304041
- new version 2.64a

* Sun Oct 07 2012 fwang <fwang> 2.64-3.mga3
+ Revision: 303270
- rebuild for new openjpeg

* Sun Oct 07 2012 fwang <fwang> 2.64-2.mga3
+ Revision: 303164
- try to build ffmpeg engine
- fix stf fmt
- fix str fmt
- fix str fmt
- fix stf fmt
- drop old tarball
- new version 2.64

* Sat Sep 29 2012 fwang <fwang> 2.63a-7.mga3
+ Revision: 300322
- specify py3ver
- update rpm group
- rebuild for new py3.3

* Tue Aug 21 2012 fwang <fwang> 2.63a-6.mga3
+ Revision: 282896
- rebuild for new glew

* Tue Jul 31 2012 fwang <fwang> 2.63a-5.mga3
+ Revision: 276847
- add upstream patch to build with latest boost
- rebuild for new glew

* Wed May 30 2012 fwang <fwang> 2.63a-4.mga3
+ Revision: 249541
- rebuild for new boost

* Mon May 28 2012 fwang <fwang> 2.63a-3.mga3
+ Revision: 247831
- try do not promote ffmpeg now, as it is too new
- apply patch
- fix build with latest ffmpeg headers
- more static lib build

* Mon May 28 2012 fwang <fwang> 2.63a-2.mga3
+ Revision: 247768
- fix build
- br openimageio for cycle engine

* Fri May 11 2012 fwang <fwang> 2.63a-1.mga2
+ Revision: 235264
- new version 2.63a

* Fri Apr 27 2012 fwang <fwang> 2.63-1.mga2
+ Revision: 233462
- SILEN: build correctly
- new version 2.63

* Thu Apr 12 2012 fwang <fwang> 2.62-2.mga2
+ Revision: 230392
- add fedora patch to build with latest openjpeg
- rebuild for new openjpeg

* Fri Feb 17 2012 fwang <fwang> 2.62-1.mga2
+ Revision: 210042
- br boost
- new version 2.62

* Fri Dec 23 2011 fwang <fwang> 2.61-2.mga2
+ Revision: 186497
- rebuild for new tiff

* Thu Dec 15 2011 fwang <fwang> 2.61-1.mga2
+ Revision: 181678
- new version 2.61

* Sun Nov 20 2011 fwang <fwang> 2.60a-3.mga2
+ Revision: 169769
- hardcode python3 usage

* Tue Oct 25 2011 fwang <fwang> 2.60a-2.mga2
+ Revision: 158008
- requires python3

* Tue Oct 25 2011 fwang <fwang> 2.60a-1.mga2
+ Revision: 157935
- new version 2.60a

* Thu Oct 20 2011 fwang <fwang> 2.60-1.mga2
+ Revision: 156766
- new version 2.60

* Fri Oct 07 2011 fwang <fwang> 2.59-5.mga2
+ Revision: 152638
- rebuild for new openjpeg

* Fri Oct 07 2011 fwang <fwang> 2.59-4.mga2
+ Revision: 152604
- rebuild for new openjpeg

* Mon Oct 03 2011 fwang <fwang> 2.59-3.mga2
+ Revision: 151161
- rebuild for new glew

* Mon Sep 12 2011 fwang <fwang> 2.59-2.mga2
+ Revision: 142630
- rebuild for new libpng
- new version 2.59
- add req for scriptles

* Sat Jul 09 2011 fwang <fwang> 2.58a-1.mga2
+ Revision: 120831
- new version 2.58a

* Tue Jun 28 2011 fwang <fwang> 2.58-1.mga2
+ Revision: 115153
- new version 2.58 (python3.2 based)

* Mon May 30 2011 pterjan <pterjan> 2.49b-10.mga1
+ Revision: 100764
- Rebuild with fixed mkrel

* Sun May 29 2011 tmb <tmb> 2.49b-9.mga1.
+ Revision: 100733
- bump rel for missing packages

  + dmorgan <dmorgan>
    - Revert to blender 2.49b

* Tue May 17 2011 dmorgan <dmorgan> 2.57b-3.mga1
+ Revision: 99512
- New version ( from mandriva )

* Mon May 09 2011 ahmad <ahmad> 2.49b-8.mga1
+ Revision: 96662
- Drop BR esound-devel, phasing out esound from the distro

* Sun Mar 27 2011 blino <blino> 2.49b-7.mga1
+ Revision: 78147
- really fix printf format for SCA_ExpressionController.cpp (from upstream SVN)
- use _real_vendor macro for desktop files naming
- remove old distro name and version checks
- remove unused python24 patch
- remove old version checks, mime types and menus
- imported package blender

